<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.7
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2021 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Helpers\Fields;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

class DimensionsHelper
{
	/**
	 * Parses the Dimensions field data
	 * 
	 * @param   array     $dimensions	  Data array
	 * @param   string    $prefix 		  The prefix
	 * @param   boolean   $important 	  Whether to add !important
	 * @param   boolean   $prefix_only 	  Each dimension contains a [dimension => [key, value]] i.e. [padding => [top => 50]] produces [padding-top: 50].
	 * In width we have [width => [value => 100]] that produces [width-value: 100] which is not what we want. With this enabled, we return [width: 100]
	 * 
	 * @return  string
	 */
	public static function parseDimensionsData($dimensions, $prefix, $important = false, $prefix_only = false)
	{
		if (empty($prefix))
		{
			return [];
		}

		if (!is_string($prefix))
		{
			return [];
		}

		if (!is_bool($prefix_only))
		{
			return [];
		}
		
		$dimensions = (array) $dimensions;
		
		$unit = isset($dimensions['unit']) ? $dimensions['unit'] : 'px';

		// skip auto units
		if ($unit == 'auto')
		{
			return [];
		}

		// remove unit and linked keys
		unset($dimensions['unit']);
		unset($dimensions['linked']);

		if (empty($dimensions))
		{
			return [];
		}
		
		$prefix = !empty($prefix) ? $prefix . (!$prefix_only ? '-' : '') : '';
		$suffix = ($important) ? ' !important' : '';
		
		$data = [];

		foreach ($dimensions as $key => $value)
		{
			if (!is_string($value) && !is_int($value))
			{
				continue;
			}
			
			if (empty($value) && $value != '0')
			{
				continue;
			}

			$key_suffix = $prefix_only ? '' : $key;
			
			$data[$prefix . $key_suffix] = $value . $unit . $suffix;
		}

		return $data;
	}

	/**
	 * Parses the Dimensions field data as Border Radius
	 * 
	 * @param   array     $dimensions	  Data array
	 * @param   boolean   $important 	  Whether to add !important
	 * 
	 * @return  string
	 */
	public static function parseDimensionsBorderRadiusData($dimensions, $important = false)
	{
		if (empty($dimensions))
		{
			return [];
		}
		
		$dimensions = (array) $dimensions;
		
		$unit = isset($dimensions['unit']) ? $dimensions['unit'] : 'px';

		// remove unit and linked keys
		unset($dimensions['unit']);
		unset($dimensions['linked']);

		$suffix = ($important) ? ' !important' : '';

		$radValue = '';

		$allValuesEmpty = 0;

		$total = count($dimensions);
		$index = 1;

		foreach ($dimensions as $key => $value)
		{
			if (!is_string($value) && !is_int($value))
			{
				continue;
			}

			$prefix = ($index > 1) ? ' ' : '';

			if (empty($value) && $value != '0')
			{
				// detect empty values
				$allValuesEmpty++;
				$radValue .= $prefix . '0' . $unit;
				$index++;
				continue;
			}
			
			$radValue .= $prefix . $value . $unit;

			$index++;
		}

		// skip if no value or empty values detected
		if (empty($radValue) || $allValuesEmpty == 4)
		{
			return [];
		}
		
		$data['border-radius'] = $radValue . $suffix;
		
		return $data;
	}
}