<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.7
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2021 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Helpers;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

class WPHelper
{
    /**
     * Returns WPML data needed to get the locale for each post
     * 
     * @param   string  $item
     * @param   string  $join_clause
     * 
     * @return  array
     */
    public static function getWPMLQueryData($item = 'p.ID', $join_clause = PostsBaseHelper::join_clause)
    {
		if (!class_exists('SitePress'))
		{
            return [];
        }

        global $wpdb;

        $locale = get_locale();
        $lang_explode = explode('_', $locale);

        $select = ',iclt.language_code as lang';
        $join = "LEFT JOIN {$wpdb->prefix}icl_translations as iclt ON iclt.element_id = {$item} {$join_clause}";

        return [
            'select' => $select,
            'join' => $join,
            'lang_code' => $lang_explode[0]
        ];
    }

    /**
     * Retives the WPML Flag image from country code
     * 
     * @param   string   $code
     * 
     * @return  string
     */
    public static function getWPMLFlagUrlFromCode($code)
    {
        if (!class_exists('SitePress'))
        {
            return '';
        }

        if (empty($code))
        {
            return '';
        }
        
        global $wpdb;
        $wpml_flags = new \WPML_Flags( $wpdb, new \icl_cache( 'flags', true ), new \WP_Filesystem_Direct( null ) );

        return '<img src="' . $wpml_flags->get_flag_url($code) . '" style="width:18px;height:12px;" alt="wpml flag image" />';
    }

	/**
	 * Returns the current page ID
	 * 
	 * @return  mixed
	 */
	public static function getPageID()
	{
        global $wp_query;
        $current_object_id = $wp_query->post;

        if (!is_front_page() && is_home())
        {
            return (int) get_option( 'page_for_posts' );
        }
        
        if (!$current_object_id)
        {
            return null;
        }

        return (int) $current_object_id->ID;
    }
    
	/**
	 * Checks and returns the active plugins from the a list of plugin names.
	 * 
	 * @param   array  $plugins
	 * 
	 * @return  array
	 */
	public static function getActivePluginsFromList($plugins)
	{
		if (!$plugins)
		{
			return [];
		}

		if (!is_array($plugins))
		{
			return [];
		}

		$active = [];

		foreach ($plugins as $key => $value)
		{
			if (!self::isPluginActive($key))
			{
				continue;
			}

			$active[$key] = $value;
		}
		
		return $active;
    }
    
    /**
     * Checks whether a plugin is active via its plugin name.
     * 
     * @param   string   $plugin_name
     * 
     * @return  boolean
     */
    public static function isPluginActive($plugin_name)
    {
        if (!$plugin_name || !is_string($plugin_name))
        {
            return false;
        }

        $plugin = $plugin_name . '/' . $plugin_name . '.php';
            
        return \is_plugin_active($plugin);
    }
}